from setuptools import setup

setup(name='footpy_manager',
      version='0.2',
      description='A Python package to manage matches of football.',
      packages=['footpy_manager'],
      zip_safe=False)